package de.tu_darmstadt.tk.SmartHomeNetworkSim.core.simpleImplementation;

import de.tu_darmstadt.tk.SmartHomeNetworkSim.core.Packet;
import de.tu_darmstadt.tk.SmartHomeNetworkSim.core.SmartDevice;

/**
 * Simple dummy packet for testing purposes
 *
 * @author Andreas T. Meyer-Berg
 */
public class SimplePacket extends Packet {

	/**
	 * Time the packet was sent
	 */
	private long time;

	/**
	 * Source of this packet
	 */
	private SmartDevice source;

	/**
	 * Destination of this packet
	 */
	private SmartDevice destination;

	/**
	 * Payload which was sent
	 */
	private String payload;

	/**
	 * Creates a new dummy packet without payload
	 * 
	 * @param time
	 *            time the package was created in System.currentTimeMillis
	 * @param source
	 *            SmartDevice which sent this packet
	 * @param destination
	 *            SmartDevice which should receive this packet
	 */
	public SimplePacket(long time, SmartDevice source, SmartDevice destination) {
		this.time = time;
		this.source = source;
		this.destination = destination;
		this.payload = "";
	}

	/**
	 * Creates a new dummy packet with a String as payload
	 * 
	 * @param time
	 *            time the package was created in System.currentTimeMillis
	 * @param source
	 *            SmartDevice which sent this packet
	 * @param destination
	 *            SmartDevice which should receive this packet
	 * @param payload
	 *            String which represents the payload which is encapsulated by
	 *            this packet
	 */
	public SimplePacket(long time, SmartDevice source, SmartDevice destination, String payload) {
		this.time = time;
		this.source = source;
		this.destination = destination;
		this.payload = payload;
	}

	@Override
	public Byte[] dumpBytes() {
		return this.dumpBytes();
	}

	@Override
	public String getTextualRepresentation() {
		return this.toString();
	}
	
	@Override
	public String toString() {
		String destName = destination == null ? "null" : destination.getName();
		String srcName = source == null ? "null" : source.getName();
			
		return "[SimplePacket:" + payload + " time-" + time + ";source:" + srcName + ";dest:"
				+ destName + "]";
	}

	@Override
	public String getPayload() {
		return payload == null ? "" : payload;
	}

	@Override
	public long getTimestamp() {
		return time;
	}

}
